.. kalabash-sievefilters documentation master file, created by
   sphinx-quickstart on Sun Apr  5 13:59:24 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kalabash-sievefilters's documentation!
================================================

This extension lets users create server-side message filters, using
the `kalsievelib module <http://pypi.python.org/pypi/kalsievelib>`_ (which
provides Sieve and ManageSieve clients).

Two different modes are available:

* A raw mode: you create filters using the Sieve language directly
  (advanced users)
* An assisted mode: you create filters using an intuitive form

Contents:

.. toctree::
   :maxdepth: 2

   setup
